# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class ChatMessageRole(StrEnum):
    """
    * `user` - User
    * `assistant` - Assistant
    * `system` - System
    """

    USER = "user"
    ASSISTANT = "assistant"
    SYSTEM = "system"



