# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class MessageCreateRequestSenderType(StrEnum):
    """
    * `customer` - Customer
    * `admin` - Admin
    """

    CUSTOMER = "customer"
    ADMIN = "admin"



class PatchedTicketUpdateRequestStatus(StrEnum):
    """
    * `open` - Open
    * `waiting_for_user` - Waiting for User
    * `waiting_for_admin` - Waiting for Admin
    * `resolved` - Resolved
    * `closed` - Closed
    """

    OPEN = "open"
    WAITING_FOR_USER = "waiting_for_user"
    WAITING_FOR_ADMIN = "waiting_for_admin"
    RESOLVED = "resolved"
    CLOSED = "closed"



