# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class LeadDetailStatus(StrEnum):
    """
    * `new` - New
    * `contacted` - Contacted
    * `qualified` - Qualified
    * `converted` - Converted
    * `rejected` - Rejected
    """

    NEW = "new"
    CONTACTED = "contacted"
    QUALIFIED = "qualified"
    CONVERTED = "converted"
    REJECTED = "rejected"



class LeadDetailContactType(StrEnum):
    """
    * `email` - Email
    * `whatsapp` - WhatsApp
    * `telegram` - Telegram
    * `phone` - Phone
    * `other` - Other
    """

    EMAIL = "email"
    WHATSAPP = "whatsapp"
    TELEGRAM = "telegram"
    PHONE = "phone"
    OTHER = "other"



