# Auto-generated by DjangoCFG - see CLAUDE.md

from .client import NewsletterNewsletterAPI
from .models import (
    CampaignCreateRequest,
    CampaignDetail,
    CampaignSendResponse,
    EmailLog,
    NewsletterCreateRequest,
    NewsletterDetail,
    PaginatedCampaignListList,
    PaginatedEmailLogList,
    PaginatedNewsletterListList,
    PaginatedSubscriptionListList,
    PatchedNewsletterUpdateRequest,
    SubscribeRequest,
    SubscribeResponse,
    SubscriptionList,
    UnsubscribeRequest,
)
from .sync_client import SyncNewsletterNewsletterAPI

__all__ = [
    "NewsletterNewsletterAPI",
    "SyncNewsletterNewsletterAPI",
    "CampaignCreateRequest",
    "CampaignDetail",
    "CampaignSendResponse",
    "EmailLog",
    "NewsletterCreateRequest",
    "NewsletterDetail",
    "PaginatedCampaignListList",
    "PaginatedEmailLogList",
    "PaginatedNewsletterListList",
    "PaginatedSubscriptionListList",
    "PatchedNewsletterUpdateRequest",
    "SubscribeRequest",
    "SubscribeResponse",
    "SubscriptionList",
    "UnsubscribeRequest",
]