# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class CampaignDetailStatus(StrEnum):
    """
    * `draft` - Draft
    * `sending` - Sending
    * `sent` - Sent
    * `failed` - Failed
    """

    DRAFT = "draft"
    SENDING = "sending"
    SENT = "sent"
    FAILED = "failed"



class EmailLogStatus(StrEnum):
    """
    * `pending` - Pending
    * `sent` - Sent
    * `failed` - Failed
    """

    PENDING = "pending"
    SENT = "sent"
    FAILED = "failed"



