# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class CustomerInvoiceDetailStatus(StrEnum):
    """
    * `created` - Created
    * `waiting` - Waiting for payment
    * `paid` - Paid
    * `expired` - Expired
    * `underpaid` - Underpaid
    * `overpaid` - Overpaid
    * `cancelled` - Cancelled
    """

    CREATED = "created"
    WAITING = "waiting"
    PAID = "paid"
    EXPIRED = "expired"
    UNDERPAID = "underpaid"
    OVERPAID = "overpaid"
    CANCELLED = "cancelled"



class CustomerTransactionResponseTransactionType(StrEnum):
    """
    * `deposit` - Deposit
    * `withdrawal` - Withdrawal
    * `refund` - Refund
    * `fee` - Fee
    * `adjustment` - Adjustment
    """

    DEPOSIT = "deposit"
    WITHDRAWAL = "withdrawal"
    REFUND = "refund"
    FEE = "fee"
    ADJUSTMENT = "adjustment"



class CustomerWithdrawalResponseStatus(StrEnum):
    """
    * `pending` - Pending
    * `approved` - Approved
    * `processing` - Processing
    * `completed` - Completed
    * `rejected` - Rejected
    * `cancelled` - Cancelled
    """

    PENDING = "pending"
    APPROVED = "approved"
    PROCESSING = "processing"
    COMPLETED = "completed"
    REJECTED = "rejected"
    CANCELLED = "cancelled"



