# Auto-generated by DjangoCFG - see CLAUDE.md

from enum import Enum


class StrEnum(str, Enum):
    """String Enum for Python 3.10+ compatibility."""


class ArchiveJobStatusStatus(StrEnum):
    """
    Current job status
    * `queued` - queued
    * `processing` - processing
    * `success` - success
    * `error` - error
    """

    QUEUED = "queued"
    PROCESSING = "processing"
    SUCCESS = "success"
    ERROR = "error"



class DataSourceSourceType(StrEnum):
    """
    * `github_repo` - GitHub Repository
    """

    GITHUB_REPO = "github_repo"



class DataSourceCrawlStatus(StrEnum):
    """
    * `pending` - Pending
    * `processing` - Processing
    * `completed` - Completed
    * `failed` - Failed
    """

    PENDING = "pending"
    PROCESSING = "processing"
    COMPLETED = "completed"
    FAILED = "failed"



